@@ -1,4 +1,4 @@
-#include <Rcpp.h>
+//#include <Rcpp.h>
 #include <RcppArmadillo.h>
 #include <iostream>
 #include <vector>
